==> hazelcast-all-3.5.4-sources.jar: com/hazelcast/map/impl/operation/PartitionWideEntryOperationFactory.java <==
/*
 * Copyright (c) 2008-2015, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;

import com.hazelcast.map.EntryProcessor;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;
import com.hazelcast.spi.OperationFactory;
import java.io.IOException;

public class PartitionWideEntryOperationFactory implements OperationFactory {

    private String name;
    private EntryProcessor entryProcessor;

    public PartitionWideEntryOperationFactory() {
    }

    public PartitionWideEntryOperationFactory(String name, EntryProcessor entryProcessor) {
        this.name = name;
        this.entryProcessor = entryProcessor;
    }

    @Override
    public Operation createOperation() {
        return new PartitionWideEntryOperation(name, entryProcessor);
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeUTF(name);
        out.writeObject(entryProcessor);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        name = in.readUTF();
        entryProcessor = in.readObject();
    }
}

==> hazelcast-all-3.8.9-sources.jar: com/hazelcast/map/impl/operation/PartitionWideEntryOperationFactory.java <==
/*
 * Copyright (c) 2008-2017, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;

import com.hazelcast.map.EntryProcessor;
import com.hazelcast.map.impl.MapDataSerializerHook;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;

import java.io.IOException;

public class PartitionWideEntryOperationFactory extends AbstractMapOperationFactory {

    private String name;
    private EntryProcessor entryProcessor;

    public PartitionWideEntryOperationFactory() {
    }

    public PartitionWideEntryOperationFactory(String name, EntryProcessor entryProcessor) {
        this.name = name;
        this.entryProcessor = entryProcessor;
    }

    @Override
    public Operation createOperation() {
        return new PartitionWideEntryOperation(name, entryProcessor);
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeUTF(name);
        out.writeObject(entryProcessor);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        name = in.readUTF();
        entryProcessor = in.readObject();
    }

    @Override
    public int getId() {
        return MapDataSerializerHook.PARTITION_WIDE_ENTRY_FACTORY;
    }
}
